pub struct PathCommand {
pub path: PaintPath,
pub paint_bounds: Rect,
pub transform: Transform,
pub action: PaintPathAction,
}Expand description
A path and its geometry information are friendly to paint and cache.
Fields
path: PaintPathThe path to painting, and its axis is relative to the bounds.
paint_bounds: RectThe bounds after path applied transform.
transform: Transformaction: PaintPathActionImplementations